import type { Ref } from 'vue';
import type { ToRefs } from 'vue';

/**
 * @public
 */
export declare function calcTotalPageSize(perPageSize: number, totalSize: number): number;

/**
 * @public
 */
export declare function createRange(last: number, first?: number): number[];

/**
 * @public
 */
export declare function isValidPageSize(currentPage: Ref<number>, totalPage: Ref<number>): boolean;

/**
 * Modify currentPage if it is considered invalid
 * @public
 */
export declare function useGuaranteePageSize(currentPage: Ref<number>, totalPage: Ref<number>): void;

/**
 * @public
 */
export declare function usePagination({ currentPage, perPageSize, totalSize, }: UsePaginationParams): ToRefs<UsePaginationReturnType>;

/**
 * @public
 */
export declare interface UsePaginationParams {
    /**
     * Current page number
     */
    currentPage: Ref<number>;
    /**
     * Maximum size of each page
     */
    perPageSize: Ref<number>;
    /**
     * Total size of items
     */
    totalSize: Ref<number>;
}

/**
 * @public
 */
export declare interface UsePaginationReturnType {
    /**
     * Current page number
     */
    currentPage: number;
    /**
     * Maximum size of each page
     */
    perPageSize: number;
    /**
     * Total size of items
     */
    totalSize: number;
    /**
     * Size of current page
     * @example
     * If perPageSize is 10, currentPage is 5, and totalSize is 52
     * ```
     * console.log(currentSize) // 10 (41~50)
     * ```
     * @example
     * If perPageSize is 10, currentPage is 6, and totalSize is 52
     * ```
     * console.log(currentSize) // 2 (51~52)
     * ```
     */
    readonly currentSize: number;
    /**
     * Total page numbers
     * @example
     * If perPageSize is 10, and totalSize is 50
     * ```
     * console.log(totalPage) // 5
     * ```
     * @example
     * If perPageSize is 10, and totalSize is 51
     * ```
     * console.log(totalPage) // 6
     * ```
     */
    readonly totalPage: number;
    /**
     * A range from 1 to the totalPage
     * @example
     * If perPageSize is 10 and totalSize is 50:
     * ```
     * console.log(pageRange) // [1, 2, 3, 4, 5]
     * ```
     */
    readonly pageRange: number[];
    /**
     * 1-indexed of first item of current page
     * @example
     * If perPageSize is 10, currentPage is 5, and totalSize is 50
     * ```
     * console.log(currentStartSize) // 41 (41~50)
     * ```
     */
    readonly currentStartSize: number;
    /**
     * 1-indexed of last item of current page
     * @example
     * If perPageSize is 10, currentPage is 5, and totalSize is 52
     * ```
     * console.log(currentEndSize) // 50 (41~50)
     * ```
     * @example
     * If perPageSize is 10, currentPage is 6, and totalSize is 52
     * ```
     * console.log(currentEndSize) // 52
     * ```
     */
    readonly currentEndSize: number;
    /**
     * Whether current page is equals to first page
     */
    readonly isFirstPage: boolean;
    /**
     * Always be 1
     */
    readonly firstPage: number;
    /**
     * Whether current page is equals to last page
     */
    readonly isLastPage: boolean;
    /**
     * Equals to totalPage
     */
    readonly lastPage: number;
    /**
     * Whether current page is not equals to first page
     */
    readonly hasPrevPage: boolean;
    /**
     * The previous number of current page
     */
    readonly prevPage: number;
    /**
     * Whether current page is not equals to last page
     */
    readonly hasNextPage: boolean;
    /**
     * The next number of current page
     */
    readonly nextPage: number;
}

/**
 * @public
 */
export declare function validatePageNumber(name: string, number: unknown): void;

export { }
